@@ -1103,15 +1103,21 @@ get_link_name (char *name, int count)
 {
 	char *result;
 	char *unescaped_name;
+	char *unescaped_tmp_name;
 	char *unescaped_result;
+	char *new_file;
 
 	const char *format;
 	
 	g_assert (name != NULL);
 
-	unescaped_name = gnome_vfs_unescape_string (name, "/");
+	unescaped_tmp_name = gnome_vfs_unescape_string (name, "/");
 	g_free (name);
 
+	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
+					     NULL, NULL, NULL);
+	g_free (unescaped_tmp_name);
+
 	if (count < 1) {
 		g_warning ("bad count in get_link_name");
 		count = 1;
@@ -1164,11 +1170,12 @@ get_link_name (char *name, int count)
 		}
 		unescaped_result = g_strdup_printf (format, count, unescaped_name);
 	}
-
-	result = gnome_vfs_escape_path_string (unescaped_result);
+	new_file = g_filename_from_utf8 (unescaped_result, -1, NULL, NULL, NULL);
+	result = gnome_vfs_escape_path_string (new_file);
 	
 	g_free (unescaped_name);
 	g_free (unescaped_result);
+	g_free (new_file);
 
 	return result;
 }
@@ -1455,18 +1462,25 @@ static char *
 get_next_duplicate_name (char *name, int count_increment)
 {
 	char *unescaped_name;
+	char *unescaped_tmp_name;
 	char *unescaped_result;
 	char *result;
+	char *new_file;
 
-	unescaped_name = gnome_vfs_unescape_string (name, "/");
+	unescaped_tmp_name = gnome_vfs_unescape_string (name, "/");
 	g_free (name);
 
+	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
+					     NULL, NULL, NULL);
+	g_free (unescaped_tmp_name);
+
 	unescaped_result = get_duplicate_name (unescaped_name, count_increment);
 	g_free (unescaped_name);
 
-	result = gnome_vfs_escape_path_string (unescaped_result);
+	new_file = g_filename_from_utf8 (unescaped_result, -1, NULL, NULL, NULL);
+	result = gnome_vfs_escape_path_string (new_file);
 	g_free (unescaped_result);
-	
+	g_free (new_file);
 	return result;
 }
 
@@ -2126,6 +2140,7 @@ nautilus_file_operations_new_folder (GtkWidget *parent_view,
 {
 	GList *target_uri_list;
 	GnomeVFSURI *uri, *parent_uri;
+	char *dirname;
 	NewFolderTransferState *state;
 
 	state = g_new (NewFolderTransferState, 1);
@@ -2137,7 +2152,10 @@ nautilus_file_operations_new_folder (GtkWidget *parent_view,
 	/* pass in the target directory and the new folder name as a destination URI */
 	parent_uri = gnome_vfs_uri_new (parent_dir);
 	/* localizers: the initial name of a new folder  */
-	uri = gnome_vfs_uri_append_file_name (parent_uri, _("untitled folder"));
+
+	dirname = g_filename_from_utf8 (_("untitled folder"), -1, NULL, NULL, NULL);
+	uri = gnome_vfs_uri_append_file_name (parent_uri, dirname);
+	g_free (dirname);
 	target_uri_list = g_list_prepend (NULL, uri);
 	
 	gnome_vfs_async_xfer (&state->handle, NULL, target_uri_list,
